# Fundamental Astrometric Catalog Tools (FACT)

A python package for processing fundamental astrometric catalogs.

The package consists of several parts, whose names and functions are listed
below.

- cat_parser: read commonly used astrometric catalogs, for example,
ICRF3 catalogs.

- cat_tools: compare different catalogs and compute the position and proper
motion differences

- solve_parser: read the output files of the VLBI global solution
generated by the Calc/Solve software.

- vlbi_tools: parse different kinds of VLBI products mainly available at [Paris Observatory Geodetic VLBI Center](https://ivsopar.obspm.fr/)(OPAR)

- vsh: catalog analyses based on the vector spherical harmonics (VSH)

The mannual is under development. Comments are welcomed.
